==> flutter_webview_desktop-0.0.12-dev.tar.gz: windows/webview_load.cc <==
#include "webview_bridge.h"
#include "include/wrapper/cef_helpers.h"
#include "include/cef_parser.h"

// Returns a data: URI with the specified contents.
std::string GetDataURI(const std::string &data, const std::string &mime_type)
{
    return "data:" + mime_type + ";base64," +
           CefURIEncode(CefBase64Encode(data.data(), data.size()), false)
               .ToString();
}
void WebviewClient::OnLoadError(CefRefPtr<CefBrowser> browser,
                                CefRefPtr<CefFrame> frame,
                                ErrorCode errorCode,
                                const CefString &errorText,
                                const CefString &failedUrl)
{
    CEF_REQUIRE_UI_THREAD();

    // Allow Chrome to show the error page.
    if (IsChromeRuntimeEnabled())
        return;

    // Don't display an error for downloaded files.
    if (errorCode == ERR_ABORTED)
        return;

    // Display a load error message using a data: URI.
    std::stringstream ss;
    ss << "<html><body bgcolor=\"white\">"
          "<h2>Failed to load URL "
       << std::string(failedUrl) << " with error " << std::string(errorText)
       << " (" << errorCode << ").</h2></body></html>";

    frame->LoadURL(GetDataURI(ss.str(), "text/html"));
}
void WebviewClient::OnLoadStart(CefRefPtr<CefBrowser> browser,
                                CefRefPtr<CefFrame> frame,
                                TransitionType transition_type)
{
    std::cout << "Test  OnLoadStart " << browser_->GetMainFrame()->GetURL() << std::endl;
    if (load_state_callback_)
    {
        load_state_callback_(WebviewClientLoadState::Start);
    }
}
void WebviewClient::OnLoadingStateChange(CefRefPtr<CefBrowser> browser,
                                         bool isLoading,
                                         bool canGoBack,
                                         bool canGoForward)
{
    std::cout << "Test  OnLoadingStateChange " << browser_->GetMainFrame()->GetURL() << std::endl;
    if (load_state_callback_)
    {
        if(isLoading){
            load_state_callback_(WebviewClientLoadState::Loading);
        }
        else{
            load_state_callback_(WebviewClientLoadState::Completed);
        }
 
    }

    if(history_changed_callback_){
        history_changed_callback_({canGoBack,canGoForward});
    }
}
void WebviewClient::OnLoadEnd(CefRefPtr<CefBrowser> browser,
                              CefRefPtr<CefFrame> frame,
                              int httpStatusCode)
{
    std::cout << "Test  OnLoadEnd " << browser_->GetMainFrame()->GetURL() << std::endl;
    if (load_state_callback_)
    {
        load_state_callback_(WebviewClientLoadState::Completed);
    }
}

==> flutter_webview_desktop-0.0.19-dev.tar.gz: windows/webview_load.cc <==
#include "webview_bridge.h"
#include "include/wrapper/cef_helpers.h"
#include "include/cef_parser.h"

// Returns a data: URI with the specified contents.
std::string GetDataURI(const std::string &data, const std::string &mime_type)
{
    return "data:" + mime_type + ";base64," +
           CefURIEncode(CefBase64Encode(data.data(), data.size()), false)
               .ToString();
}
void WebviewClient::OnLoadError(CefRefPtr<CefBrowser> browser,
                                CefRefPtr<CefFrame> frame,
                                ErrorCode errorCode,
                                const CefString &errorText,
                                const CefString &failedUrl)
{
    CEF_REQUIRE_UI_THREAD();

    // Allow Chrome to show the error page.
    if (IsChromeRuntimeEnabled())
        return;

    // Don't display an error for downloaded files.
    if (errorCode == ERR_ABORTED)
        return;

    // Display a load error message using a data: URI.
    std::stringstream ss;
    ss << "<html><body bgcolor=\"white\">"
          "<h2>Failed to load URL "
       << std::string(failedUrl) << " with error " << std::string(errorText)
       << " (" << errorCode << ").</h2></body></html>";

    frame->LoadURL(GetDataURI(ss.str(), "text/html"));
}
void WebviewClient::OnLoadStart(CefRefPtr<CefBrowser> browser,
                                CefRefPtr<CefFrame> frame,
                                TransitionType transition_type)
{
    //std::cout << "Test  OnLoadStart " << browser_->GetMainFrame()->GetURL() << std::endl;
    if(!browser_){
        return;
    }
    if (load_state_callback_)
    {
        load_state_callback_(WebviewClientLoadState::Start);
    }
}
void WebviewClient::OnLoadingStateChange(CefRefPtr<CefBrowser> browser,
                                         bool isLoading,
                                         bool canGoBack,
                                         bool canGoForward)
{
    //std::cout << "Test  OnLoadingStateChange " << browser_->GetMainFrame()->GetURL() << std::endl;
    if (!browser_)
    {
        return;
    }
    if (load_state_callback_)
    {
        if(isLoading){
            load_state_callback_(WebviewClientLoadState::Loading);
        }
        else{
            load_state_callback_(WebviewClientLoadState::Completed);
        }
 
    }

    if(history_changed_callback_){
        history_changed_callback_({canGoBack,canGoForward});
    }
}
void WebviewClient::OnLoadEnd(CefRefPtr<CefBrowser> browser,
                              CefRefPtr<CefFrame> frame,
                              int httpStatusCode)
{
    //std::cout << "Test  OnLoadEnd " << browser_->GetMainFrame()->GetURL() << std::endl;
    if (!browser_)
    {
        return;
    }
    if (load_state_callback_)
    {
        load_state_callback_(WebviewClientLoadState::Completed);
    }
}
